Welcome to smonad's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 3

   intro
   reference
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
